@@ -1,19 +1,22 @@
+from typing import Any
+
 from indico import IndicoClient, IndicoConfig
 from indico.errors import IndicoAuthenticationFailed, IndicoRequestError
-from indico_toolkit.errors import ToolkitAuthError
-from indico_toolkit.retry import retry
+
+from .errors import ToolkitAuthError
+from .retry import retry
 
 
-@retry((IndicoRequestError, ConnectionError))
-def create_client(
+@retry(IndicoRequestError, ConnectionError)
+def create_client(  # type: ignore[no-any-unimported]
     host: str,
-    api_token_path: str = None,
-    api_token_string: str = None,
+    api_token_path: "str | None" = None,
+    api_token_string: "str | None" = None,
     verify_ssl: bool = True,
-    **kwargs,
+    **kwargs: Any,
 ) -> IndicoClient:
     """
-    Instantiate your Indico API client. 
+    Instantiate your Indico API client.
     Specify either the path to your token or the token string itself.
     """
     config = IndicoConfig(
@@ -27,5 +30,6 @@ def create_client(
         return IndicoClient(config)
     except IndicoAuthenticationFailed as e:
         raise ToolkitAuthError(
-            f"{e}\n\n Ensure that you are using your most recently downloaded token with the correct host URL"
+            f"{e}\nEnsure that you are using your most recently downloaded token with "
+            "the correct host URL"
         )
