@@ -1,3 +1,7 @@
 from .ondoc_object import OnDoc
 from .standard_object import StandardOcr
-from .customocr_object import CustomOcr
+
+__all__ = (
+    "OnDoc",
+    "StandardOcr",
+)
