@@ -1,25 +1,28 @@
-from typing import List, Dict, Set
-
-from indico_toolkit.errors import ToolkitInputError
-from .extractions import Extractions
+from ..errors import ToolkitInputError
 from .classification import Classification, ClassificationMGP
+from .extractions import Extractions
+
 
 class Predictions:
     """
     Factory class for predictions
     """
+
     @staticmethod
     def get_obj(predictions):
         """
         Returns:
         Extractions object or Classification object depending on predictions type
         """
-        if type(predictions) == list:
+        if isinstance(predictions, list):
             return Extractions(predictions)
-        elif type(predictions) == dict:
+        elif isinstance(predictions, dict):
             if "label" in predictions:
                 return Classification(predictions)
             else:
                 return ClassificationMGP(predictions)
         else:
-            raise ToolkitInputError(f"Unable to process predictions with type {type(predictions)}. Predictions: {predictions}")
+            raise ToolkitInputError(
+                f"Unable to process predictions with type {type(predictions)}. "
+                f"Predictions: {predictions}"
+            )
